@@ -49,7 +49,7 @@ class Logger():
 
         if self.use_wandb:
             wandb.init(entity=wandb_entity, project=wandb_project, name=wandb_name
-                       , resume="allow", id = wandb_id, dir=os.path.join(wandb_dir, 'wandb')
+                       , resume="allow", id = wandb_id, dir=wandb_dir
                        , config=args)
 
             if args: args.wandb_id = wandb.config.id = wandb.run.id
