@@ -24,7 +24,8 @@ class GPU_Worker():
         handle = pynvml.nvmlDeviceGetHandleByIndex(id)
         use = pynvml.nvmlDeviceGetUtilizationRates(handle)
         # ratio = 0.5 * (float(use.gpu + float(use.memory)))
-        ratio = float(use.memory)
+        # ratio = float(use.memory)
+        ratio = float(use.gpu)
         return ratio
 
     def setGPU(self):
